<h2 algin="center"> amifast: simple powerful benchmarking with Python</h2>

---

_Contents:_ **[Installation and usage](#installation-and-usage)** |
**[Contributing](#contributing)** | **[Change Log](#change-log)** |
**[Authors](#authors)**

---

## Installation and Usage

### Installation


### Usage

```python
```

### Examples

Examples can be found in the [Examples](examples/) directory.

### Command line options

Will be added at a later date.

## License

MIT

## Contributing

More details can be found in [CONTRIBUTING](CONTRIBUTING.md)

## Change Log

Nothing has been recorded here so far...

## Authors

Developed by [Julian Niedermeier](mailto:jpniedermeier@gmail.com)
